@@ -156,7 +156,8 @@ def Gamma_diss(T: float, T1: float, molecule: MoleculeQuasi, atom1: Atom, atom2:
     T : float
         the temperature of the mixture
     T1 : float
-        the temperature of the first vibrational level of the molecule which dissociates
+        the temperature of the first vibrational level of the molecule which dissociates (if the one-temperature
+        approximation is used, can be set to any value)
     molecule : MoleculeMultiT or MoleculeOneT
         the molecule which dissociates
     atom1 : Atom
@@ -180,11 +181,12 @@ def Gamma_diss(T: float, T1: float, molecule: MoleculeQuasi, atom1: Atom, atom2:
 
     """
     if isinstance(molecule, MoleculeMultiT):
-        return raw_Gamma_diss(T, T1, molecule.vibr[1], molecule.Z_int(T, T1), molecule.mass, atom1.mass, atom2.mass,
-                              molecule.diss_offset, n_molecule, n_atom1, n_atom2, diss_level)
+        return raw_Gamma_diss(T, T1, molecule.vibr[1], molecule.Z_int(T, T1), molecule.mass,
+                              atom1.mass, atom2.mass, molecule.diss - molecule.vibr_zero,
+                              n_molecule, n_atom1, n_atom2, diss_level)
     else:
         return raw_Gamma_diss_oneT(T, molecule.Z_int(T), molecule.mass, atom1.mass, atom2.mass,
-                                   molecule.diss_offset, n_molecule, n_atom1, n_atom2)
+                                   molecule.diss, n_molecule, n_atom1, n_atom2)
 
 
 def find_natom_diss_eq(T: float, molecule: MoleculeOneT, atom: Atom, n: float, relative: bool=True) -> float:
