@@ -413,7 +413,7 @@ def vv_collisions_fho(T: float, T1_1: float, T1_2: float, idata: np.ndarray,
 
     Raises
     KineticlibError
-        If ``molecule1`` are of different ``molecule2``
+        If ``molecule1`` and  ``molecule2`` are of different types
     
     """
     if isinstance(molecule1, MoleculeMultiT) and isinstance(molecule2, MoleculeMultiT):
@@ -873,7 +873,7 @@ def raw_vt_integral_fho(T: float, deg: int, mass: float, beta: float, vssc: floa
     ve_after : float
         the vibrational energy of the molecule after the transition
     molecule_vibr_zero : float
-        the energy of the 0-th vibrational level
+        the energy of the 0-th vibrational level (with no offset)
     molecule_diss : float
         the dissociation energy of the molecule which undergoes the transition (with no offset)
     i : int
@@ -942,7 +942,7 @@ def raw_vt_integral_rigid_sphere_fho(T: float, deg: int, sigma: float, mass: flo
     ve_after : float
         the vibrational energy of the molecule after the transition
     molecule_vibr_zero : float
-        the energy of the 0-th vibrational level
+        the energy of the 0-th vibrational level (with no offset)
     molecule_diss : float
         the dissociation energy of the molecule which undergoes the transition (with no offset)
     i : int
