@@ -10,6 +10,7 @@ import numpy as np
 from scipy import constants
 from scipy.misc import factorial
 from .errors import KineticlibError
+from math import exp, cosh, atan, sinh
 
 
 def fact_div_fact(start: int, end: int) -> float:
@@ -156,12 +157,12 @@ def vt_probability(g: float, T: float, mass: float, beta: float, ve_before: floa
 
     if vel < 0.0:
         return 0.0
-    phi = 2.0 * np.arctan(((2.0 * (molecule_diss + molecule_vibr_zero) / mass) ** 0.5) / vel)
+    phi = 2.0 * atan(((2.0 * (molecule_diss + molecule_vibr_zero) / mass) ** 0.5) / vel)
 
-    eps = (np.cosh((1.0 + phi) * omega / (beta * vel))
-           / (np.sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
+    eps = (cosh((1.0 + phi) * omega / (beta * vel))
+           / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
     eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
-    return ns * (eps ** s) * np.exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1)) / (factorial(s) ** 2)
+    return ns * (eps ** s) * exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1)) / (factorial(s) ** 2)
 
 
 def vt_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before: float, ve_after: float, i: int, delta: int,
@@ -203,38 +204,38 @@ def vt_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before: floa
 
     if delta == 1:
         omega = (ve_after - ve_before) / constants.hbar
-        phi = 2.0 * np.arctan(((2.0 * depth / mass) ** 0.5) / vel)
+        phi = 2.0 * atan(((2.0 * depth / mass) ** 0.5) / vel)
 
-        eps = (np.cosh((1.0 + phi) * omega / (beta * vel))
-               / (np.sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
+        eps = (cosh((1.0 + phi) * omega / (beta * vel))
+               / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
         eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
-        return eps * np.exp(-(i + 1) * eps)
+        return eps * exp(-(i + 1) * eps)
     elif delta == -1:
         omega = (ve_before - ve_after) / constants.hbar
-        phi = 2.0 * np.arctan(((2.0 * depth / mass) ** 0.5) / vel)
+        phi = 2.0 * atan(((2.0 * depth / mass) ** 0.5) / vel)
 
-        eps = (np.cosh((1.0 + phi) * omega / (beta * vel))
-               / (np.sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
+        eps = (cosh((1.0 + phi) * omega / (beta * vel))
+               / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
         eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
-        return eps * np.exp(-i * eps)
+        return eps * exp(-i * eps)
     elif delta > 0:
         s = delta * 1.0
         omega = (ve_after - ve_before) / (delta * constants.hbar)
         ns = fact_div_fact(i, i + delta)
-        phi = 2.0 * np.arctan(((2.0 * depth / mass) ** 0.5) / vel)
-        eps = (np.cosh((1.0 + phi) * omega / (beta * vel))
-               / (np.sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
+        phi = 2.0 * atan(((2.0 * depth / mass) ** 0.5) / vel)
+        eps = (cosh((1.0 + phi) * omega / (beta * vel))
+               / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
         eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
-        return (eps ** s) * np.exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1))
+        return (eps ** s) * exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1))
     else:
         s = -delta * 1.0
         omega = (ve_before - ve_after) / (delta * constants.hbar)
         ns = fact_div_fact(i + delta, i)
-        phi = 2.0 * np.arctan(((2.0 * depth / mass) ** 0.5) / vel)
-        eps = (np.cosh((1.0 + phi) * omega / (beta * vel))
-               / (np.sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
+        phi = 2.0 * atan(((2.0 * depth / mass) ** 0.5) / vel)
+        eps = (cosh((1.0 + phi) * omega / (beta * vel))
+               / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
         eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
-        return (eps ** s) * np.exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1))
+        return (eps ** s) * exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1))
 
 
 def vv_probability(g: float, T: float, mass: float, beta: float, ve_before1: float, ve_after1: float,
@@ -298,9 +299,9 @@ def vv_probability(g: float, T: float, mass: float, beta: float, ve_before1: flo
     if xi < 1.0 ** (-4):
         rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
     else:
-        rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
+        rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
-    return rhoxi * ns1 * ns2 * np.exp(-2.0 * rhoxi * ((ns1 * ns2) ** (1.0 / s)) / (s + 1)) / (factorial(s) ** 2)
+    return rhoxi * ns1 * ns2 * exp(-2.0 * rhoxi * ((ns1 * ns2) ** (1.0 / s)) / (s + 1)) / (factorial(s) ** 2)
 
 
 def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: float, ve_after1: float,
@@ -350,9 +351,9 @@ def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: flo
         if xi < 1.0 ** (-10):
             rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
-            rhoxi = svv * ((omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
+            rhoxi = svv * ((omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
-        return rhoxi * np.exp(-((i + 1) * k) * rhoxi)
+        return rhoxi * exp(-((i + 1) * k) * rhoxi)
     elif i_delta == -1:
         omega1 = (ve_before1 - ve_after1) / constants.hbar
         omega2 = (ve_after2 - ve_before2) / constants.hbar
@@ -361,9 +362,9 @@ def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: flo
         if xi < 1.0 ** (-10):
             rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
-            rhoxi = svv * ((omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
+            rhoxi = svv * ((omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
-        return rhoxi * np.exp(-(i * (k + 1)) * rhoxi)
+        return rhoxi * exp(-(i * (k + 1)) * rhoxi)
     elif i_delta > 0:
         s = i_delta * 1.0
         omega1 = (ve_after1 - ve_before1) / constants.hbar
@@ -373,9 +374,9 @@ def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: flo
         if xi < 1.0 ** (-10):
             rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
-            rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
+            rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
-        return rhoxi * np.exp(-2.0 * ((fact_div_fact(i, i + i_delta) * fact_div_fact(k - i_delta, k)) ** (1.0 / s))
+        return rhoxi * exp(-2.0 * ((fact_div_fact(i, i + i_delta) * fact_div_fact(k - i_delta, k)) ** (1.0 / s))
                      * rhoxi / (s + 1))
     else:
         s = -i_delta * 1.0
@@ -386,7 +387,7 @@ def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: flo
         if xi < 1.0 ** (-10):
             rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
-            rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
+            rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
-        return rhoxi * np.exp(-2.0 * ((fact_div_fact(i + i_delta, i) * fact_div_fact(k, k - i_delta)) ** (1.0 / s))
+        return rhoxi * exp(-2.0 * ((fact_div_fact(i + i_delta, i) * fact_div_fact(k, k - i_delta)) ** (1.0 / s))
                      * rhoxi / (s + 1))
\ No newline at end of file
