@@ -9,7 +9,7 @@ __status__ = "Production"
 import numpy as np
 from scipy import constants
 from .crosssection import raw_diss_integral_rigid_sphere
-from .particles import Molecule, MoleculeMultiT, Atom, MoleculeOneT, MoleculeQuasi
+from .particles import Molecule, MoleculeMultiT, Atom, MoleculeQuasi
 from math import exp
 
 
@@ -139,9 +139,14 @@ def rec_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Mol
     float
         Recombination state-to-state rate constant
     """
-    return raw_rec_rate_treanor_marrone_sts(T, model_data[0], model_data[1], molecule.Z_diss(T, i, model),
-                                            molecule.Z_rot(T), molecule.mass, atom1.mass, atom2.mass,
-                                            molecule.vibr[i], molecule.diss)
+    if isinstance(molecule, MoleculeMultiT):
+        return raw_rec_rate_treanor_marrone_sts(T, model_data[0], model_data[1], molecule.Z_diss(T, i, model),
+                                                molecule.Z_rot(T), molecule.mass, atom1.mass, atom2.mass,
+                                                molecule.vibr[i] + molecule.vibr_zero, molecule.diss)
+    else:
+        return raw_rec_rate_treanor_marrone_sts(T, model_data[0], model_data[1], molecule.Z_diss(T, i, model),
+                                                molecule.Z_rot(T), molecule.mass, atom1.mass, atom2.mass,
+                                                molecule.vibr[i], molecule.diss)
 
 
 def rec_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: Molecule, atom1: Atom, atom2: Atom, i: int,
@@ -176,9 +181,14 @@ def rec_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: Molecule, a
     float
         Recombination state-to-state rate constant
     """
-    return raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
-                                         atom2.mass, molecule.vibr[i], molecule.diss_offset,
-                                         center_of_mass, vl_dependent)
+    if isinstance(molecule, MoleculeMultiT):
+        return raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
+                                             atom2.mass, molecule.vibr[i] + molecule.vibr_zero, molecule.diss,
+                                             center_of_mass, vl_dependent)
+    else:
+        return raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
+                                             atom2.mass, molecule.vibr[i], molecule.diss,
+                                             center_of_mass, vl_dependent)
 
 
 def diss_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecule: MoleculeQuasi,
@@ -190,7 +200,8 @@ def diss_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molec
     T : float
         the temperature of the mixture
     T1 : float
-        the temperature of the first vibrational level of the molecule which dissociates
+        the temperature of the first vibrational level of the molecule which dissociates (if the one-temperature
+        approximation is used, can be set to any value)
     model_data : 1-D array-like
         dissociation model data
     molecule : MoleculeMultiT or MoleculeOneT
@@ -236,7 +247,8 @@ def diss_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Mol
     T : float
         the temperature of the mixture
     T1 : float
-        the temperature of the first vibrational level of the molecule which dissociates
+        the temperature of the first vibrational level of the molecule which dissociates (if the one-temperature
+        approximation is used, can be set to any value)
     idata : 1-D array-like
         the array of interaction data
     molecule : MoleculeMultiT or MoleculeOneT
@@ -259,18 +271,18 @@ def diss_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Mol
         for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
             res += molecule.vibr_exp(T, T1, i) \
                    * raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i] + molecule.vibr_zero,
-                                                    molecule.diss_offset, center_of_mass, vl_dependent)
+                                                    molecule.diss, center_of_mass, vl_dependent)
         return res / molecule.Z_vibr(T, T1)
     else:
         for i in range(molecule.num_vibr + 1):
             res += molecule.vibr_exp(T, i) \
-                   * raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i], molecule.diss_offset,
+                   * raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i], molecule.diss,
                                                     center_of_mass, vl_dependent)
         return res / molecule.Z_vibr(T)
 
 
 def rec_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecule: MoleculeQuasi,
-                             atom1: Atom, atom2: Atom) -> float:
+                             atom1: Atom, atom2: Atom, model: str='D6k') -> float:
     """Calculates the averaged recombination rate constant using the Treanor-Marrone model
 
     Parameters
@@ -278,7 +290,8 @@ def rec_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecu
     T : float
         the temperature of the mixture
     T1 : float
-        the temperature of the first vibrational level of the molecule which dissociates
+        the temperature of the first vibrational level of the molecule which dissociates (if the one-temperature
+        approximation is used, can be set to any value)
     model_data : 1-D array-like
         dissociation model data
     molecule : MoleculeMultiT or MoleculeOneT
@@ -287,21 +300,37 @@ def rec_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecu
         atom of the first atomic species which make up the molecule
     atom2 : Atom
         atom of the second atomic species which make up the molecule
+    model : str
+        the model for the `U` parameter to be used, possible values:
+
+            * ``'inf'`` - the U parameter in the non-equilbrium factor
+              will be equal to :math:`\\infty`
+            * ``'D6k'`` - the U parameter in the non-equilbrium factor will be equal
+              to :math:`D / 6k`, where :math:`D` is the dissociation energy of the molecule
+            * ``'3T'`` - the U parameter in the non-equilbrium factor will be equal to :math:`3T`
+
+        defaults to 'D6k'
 
     Returns
     -------
     float
         Averaged recombination rate constant
     """
+    res = 0.0
     if isinstance(molecule, MoleculeMultiT):
-        res = 0.0
         for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
-            res += raw_rec_rate_treanor_marrone(T, model_data[0], model_data[1], molecule.Z_int(T, T),
-                                                molecule.mass, atom1.mass,
-                                                atom2.mass, molecule.diss) * molecule.vibr_exp(T, T1, i)
+            res += raw_rec_rate_treanor_marrone_sts(T, model_data[0], model_data[1],
+                                                    molecule.Z_diss(T, i, model), molecule.Z_rot(T), molecule.mass,
+                                                    atom1.mass, atom2.mass, molecule.vibr[i] + molecule.vibr_zero,
+                                                    molecule.diss) * molecule.vibr_exp(T, T1, i)
+        return res / molecule.Z_vibr(T, T1)
     else:
-        return raw_rec_rate_treanor_marrone(T, model_data[0], model_data[1], molecule.Z_int(T),
-                                            molecule.mass, atom1.mass, atom2.mass, molecule.diss)
+        for i in range(molecule.num_vibr + 1):
+            res += raw_rec_rate_treanor_marrone_sts(T, model_data[0], model_data[1],
+                                                    molecule.Z_diss(T, i, model), molecule.Z_rot(T), molecule.mass,
+                                                    atom1.mass, atom2.mass, molecule.vibr[i],
+                                                    molecule.diss) * molecule.vibr_exp(T, i)
+        return res / molecule.Z_vibr(T)
 
 
 def rec_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: MoleculeQuasi, atom1: Atom, atom2: Atom,
@@ -313,7 +342,8 @@ def rec_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Mole
     T : float
         the temperature of the mixture
     T1 : float
-        the temperature of the first vibrational level of the molecule which dissociates
+        the temperature of the first vibrational level of the molecule which dissociates (if the one-temperature
+        approximation is used, can be set to any value)
     idata : 1-D array-like
         the array of interaction data
     molecule : MoleculeMultiT or MoleculeOneT
@@ -339,12 +369,12 @@ def rec_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: Mole
     if isinstance(molecule, MoleculeMultiT):
         for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
             res += raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
-                                                 atom2.mass, molecule.vibr[i], molecule.diss_offset,
-                                                 center_of_mass, vl_dependent)
+                                                 atom2.mass, molecule.vibr[i] + molecule.vibr_zero,
+                                                 molecule.diss, center_of_mass, vl_dependent)
     else:
         for i in range(molecule.num_vibr + 1):
             res += raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
-                                                 atom2.mass, molecule.vibr[i], molecule.diss_offset,
+                                                 atom2.mass, molecule.vibr[i], molecule.diss,
                                                  center_of_mass, vl_dependent)
     return res
 
@@ -361,7 +391,7 @@ def raw_k_diss_eq(T: float, arrhenius_n: float, arrhenius_A: float, molecule_dis
     arrhenius_A : float
         Arrhenius model A parameter
     molecule_diss : float
-        the dissociation energy of the molecule
+        the dissociation energy of the molecule (with no offset)
 
     Returns
     -------
@@ -388,7 +418,7 @@ def raw_diss_rate_treanor_marrone_sts(T: float, arrhenius_n: float, arrhenius_A:
     Z_diss : float
         the non-equilibrium factor
     molecule_diss : float
-        the dissociation energy of the molecule
+        the dissociation energy of the molecule (with no offset)
 
     Returns
     -------
@@ -414,9 +444,9 @@ def raw_diss_rate_rigid_sphere_sts(T: float, sigma: float, mass: float, molecule
         the collision-reduced mass :math:`m_{cd}`
     molecule_vibr : float
         the dimensional vibrational energy of the level from which the molecule dissociates (if ``vl_dependent``
-        is ``False``, can be any value)
+        is ``False``, can be any value) (with no offset)
     molecule_diss : float
-        the dissociation energy of the molecule which dissociates
+        the dissociation energy of the molecule which dissociates (with no offset)
     center_of_mass : bool, optional
         if ``True``, the kinetic energy of the collision partners will be calculated along the center-of-mass line,
         if ``False``, the total kinetic energy will be used, defaults to ``True``
@@ -460,9 +490,9 @@ def raw_rec_rate_treanor_marrone_sts(T: float, arrhenius_n: float, arrhenius_A:
         the mass of the second atom product of dissociation
     molecule_vibr : float
         the dimensional vibrational energy of the level from which the molecule dissociates (if ``vl_dependent``
-        is ``False``, can be any value)
+        is ``False``, can be any value) (with no offset)
     molecule_diss : float
-        the dissociation energy of the molecule which dissociates
+        the dissociation energy of the molecule which dissociates (with no offset)
 
     Returns
     -------
@@ -500,9 +530,9 @@ def raw_rec_rate_rigid_sphere_sts(T: float, sigma: float, mass: float, Z_rot: fl
         the mass of the second atom product of dissociation
     molecule_vibr : float
         the dimensional vibrational energy of the level from which the molecule dissociates (if ``vl_dependent``
-        is ``False``, can be any value)
+        is ``False``, can be any value) (with no offset)
     molecule_diss : float
-        the dissociation energy of the molecule which dissociates
+        the dissociation energy of the molecule which dissociates (with no offset)
     center_of_mass : bool, optional
         if ``True``, the kinetic energy of the collision partners will be calculated along the center-of-mass line,
         if ``False``, the total kinetic energy will be used, defaults to ``True``
@@ -545,7 +575,7 @@ def raw_rec_rate_treanor_marrone(T: float, arrhenius_n: float, arrhenius_A: floa
     mass_atom2 : float
         the mass of the second atom product of dissociation
     molecule_diss : float
-        the dissociation energy of the molecule which dissociates
+        the dissociation energy of the molecule which dissociates (with no offset)
 
     Returns
     -------
